@@ -1098,7 +1098,7 @@ C-----------------------------------------------------------------------
 C-----------------------------------------------------------------------
 C     STEP 1. SET NIT := 1
 C-----------------------------------------------------------------------
- 100  NIT=1
+      NIT=1
 C-----------------------------------------------------------------------
 C     STEP 2. COMPUTE rlRESDm2 AS R=Y-X*THETA
 C-----------------------------------------------------------------------
@@ -1331,7 +1331,7 @@ C-----------------------------------------------------------------------
  100  IF (IOPT.NE.3) THEN
          DO 130 K=1,NQ
  110        CALL rlRNDm2(ISEED,RND)
-            ITK=RND*N+1
+            ITK= idint(RND*N)+1
             DO 120 KK=1,K-1
                IF (ITK.EQ.IT(KK)) GOTO 110
  120        CONTINUE
@@ -1409,7 +1409,7 @@ C-----------------------------------------------------------------------
 C-----------------------------------------------------------------------
 C     STEP 6: UPDATE BEST FIT
 C-----------------------------------------------------------------------
- 600  IERR=0
+      IERR=0
       SMIN=SRES
       S0=SMIN
       DO 610 K=1,NP
